@@ -1,4 +1,4 @@
-set rcsid {$Id: capi3ref.tcl,v 1.34 2006/02/11 01:25:52 drh Exp $}
+set rcsid {$Id: capi3ref.tcl,v 1.39 2006/05/27 11:15:48 drh Exp $}
 source common.tcl
 header {C/C++ Interface For SQLite Version 3}
 puts {
@@ -176,7 +176,7 @@ api {} {
  If the busy callback is NULL, then SQLITE_BUSY is returned immediately
  upon encountering the lock.
  If the busy callback is not NULL, then the
- callback might invoked with two arguments.  The
+ callback will be invoked with two arguments.  The
  second argument is the number of prior calls to the busy callback
  for the same lock.  If the
  busy callback returns 0, then no additional attempts are made to
@@ -895,13 +895,23 @@ api {sqlite3_interrupt} {
 api {} {
 long long int sqlite3_last_insert_rowid(sqlite3*);
 } {
- Each entry in an SQLite table has a unique integer key.  (The key is
- the value of the INTEGER PRIMARY KEY column if there is such a column,
- otherwise the key is generated at random.  The unique key is always
- available as the ROWID, OID, or _ROWID_ column.)  This routine
- returns the integer key of the most recent insert in the database.
+ Each entry in an SQLite table has a unique integer key called the "rowid".
+ The rowid is always available as an undeclared column
+ named ROWID, OID, or _ROWID_.
+ If the table has a column of type INTEGER PRIMARY KEY then that column
+ is another an alias for the rowid.
 
- This function is similar to the mysql_insert_id() function from MySQL.
+ This routine
+ returns the rowid of the most recent INSERT into the database
+ from the database connection given in the first argument.  If
+ no inserts have ever occurred on this database connection, zero
+ is returned.
+
+ If an INSERT occurs within a trigger, then the rowid of the
+ inserted row is returned by this routine as long as the trigger
+ is running.  But once the trigger terminates, the value returned
+ by this routine reverts to the last value inserted before the
+ trigger fired.
 } {}
 
 api {} {
@@ -988,6 +998,11 @@ int sqlite3_open16(
  pass the resulting database handle off to another thread to use.  This
  restriction is due to goofy design decisions (bugs?) in the way some
  threading implementations interact with file locks.
+
+ Note to windows users:  The encoding used for the filename argument
+ of sqlite3_open() must be UTF-8, not whatever codepage is currently
+ defined.  Filenames containing international characters must be converted
+ to UTF-8 prior to passing them into sqlite3_open().
 }
 
 api {} {
@@ -1128,6 +1143,9 @@ int sqlite3_set_authorizer(
 #define SQLITE_UPDATE               23   /* Table Name      Column Name     */
 #define SQLITE_ATTACH               24   /* Filename        NULL            */
 #define SQLITE_DETACH               25   /* Database Name   NULL            */
+#define SQLITE_ALTER_TABLE          26   /* Database Name   Table Name      */
+#define SQLITE_REINDEX              27   /* Index Name      NULL            */
+#define SQLITE_ANALYZE              28   /* Table Name      NULL            */
 
 #define SQLITE_DENY   1   /* Abort the SQL statement with an error */
 #define SQLITE_IGNORE 2   /* Don't allow access, but don't generate an error */
@@ -1296,7 +1314,7 @@ api {} {
 }
 
 api {} {
-  int sqlite3_db_handle(sqlite3_stmt*);
+  sqlite3 *sqlite3_db_handle(sqlite3_stmt*);
 } {
  Return the sqlite3* database handle to which the prepared statement given
  in the argument belongs.  This is the same database handle that was
